@@ -17,9 +17,8 @@ def event():
 
 
 @pytest.fixture()
-def event_with_query():
-    event = {'query': {'geo': ['northamerica'], 'id': ['uuid']},
-             'credentials': {'username': 'myUser', 'password': 'myPassword!', 'api_location': 'northamerica'}}
+def cloud_control_query():
+    event = {'id': ['uuid']}
     return event
 
 
@@ -69,11 +68,11 @@ def test_get_all_servers_empty(mock_http_client_function, cloud_control_client):
 
 
 @patch('cloud_control_common.http_client.HttpClient.get_with_filters')
-def test_get_servers_with_filters(mock_http_client_function, cloud_control_client, event_with_query):
+def test_get_servers_with_filters(mock_http_client_function, cloud_control_client, cloud_control_query):
     json_file = open(os.path.join(module_dir, 'json/servers_all_pages.json'), 'r')
     mock_http_client_function.return_value = json.load(json_file)
 
-    of_type = cloud_control_client.get_servers(event_with_query)
+    of_type = cloud_control_client.get_servers(cloud_control_query)
     mock_http_client_function.assert_called_once_with("/server/server", {'id': ['uuid']})
     assert len(of_type) == 2
 
@@ -82,8 +81,7 @@ def test_get_servers_with_filters(mock_http_client_function, cloud_control_clien
 def test_get_servers_with_multi_value_filters(mock_http_client_function, cloud_control_client):
     json_file = open(os.path.join(module_dir, 'json/servers.json'), 'r')
     mock_http_client_function.return_value = json.load(json_file)
-    event = {'query': {'geo': ['northamerica'], 'id': ['uuid', 'uuid2']},
-             'credentials': {'username': 'myUser', 'password': 'myPassword!', 'api_location': 'northamerica'}}
+    event = {'id': ['uuid', 'uuid2']}
     of_type = cloud_control_client.get_servers(event)
     mock_http_client_function.assert_called_once_with("/server/server", {'id': ['uuid', 'uuid2']})
     assert len(of_type['server']) == 1
@@ -93,9 +91,7 @@ def test_get_servers_with_multi_value_filters(mock_http_client_function, cloud_c
 def test_get_servers_with_ignored_filters_excluded(mock_http_client_function, cloud_control_client):
     json_file = open(os.path.join(module_dir, 'json/servers_all_pages.json'), 'r')
     mock_http_client_function.return_value = json.load(json_file)
-    event = {'query': {'geo': ['northamerica'], 'provider_id': ['provider_id'], 'account_id': ['account_id'],
-                       'organizationId': ['organizationId']},
-             'credentials': {'username': 'myUser', 'password': 'myPassword!', 'api_location': 'northamerica'}}
+    event = {}
     of_type = cloud_control_client.get_servers(event)
     mock_http_client_function.assert_called_once_with("/server/server", {})
     assert len(of_type) == 2
@@ -132,11 +128,11 @@ def test_get_all_datacenters(mock_http_client_function, cloud_control_client):
 
 
 @patch('cloud_control_common.http_client.HttpClient.get_with_filters')
-def test_get_datacenters_with_filters(mock_http_client_function, cloud_control_client, event_with_query):
+def test_get_datacenters_with_filters(mock_http_client_function, cloud_control_client, cloud_control_query):
     json_file = open(os.path.join(module_dir, 'json/datacenters.json'), 'r')
     mock_http_client_function.return_value = json.load(json_file)
 
-    of_type = cloud_control_client.get_datacenters(event_with_query)
+    of_type = cloud_control_client.get_datacenters(cloud_control_query)
     mock_http_client_function.assert_called_once_with("/infrastructure/datacenter", {'id': ['uuid']})
     assert len(of_type['datacenter']) == 4
 
